/**
 * @class MoonplayerAutoplay
 *
 * @param {Object} mp                   Object of Moonplayer Class
 * @property {Object} el                DOMElement .media-control-button.media-control-icon
 * @property {Boolean} keepEnabled      Autoplay status
 * @method _triggerButton               Callback function on click on autoplay button
 * @method _getButtonHTML               Returns content of autoplay button
 * @method flush                        Initialize or update autoplay action
 */
function MoonplayerAutoplay(mp) {
    
    var self = this;
    
    this.el = null;
    this.keepEnabled = true;
    
    /**
     * @method _triggerButton
     */
    this._triggerButton = function() {
        self.keepEnabled = !self.keepEnabled;
        
        this.el.className = this.el.className.replace(/\s?autoplay/, '');
        
        if (self.keepEnabled) this.el.className += ' autoplay';
    };
    
    /**
     * @method _getButtonHTML
     */
    this._getButtonHTML = function() {
        return '<svg class="on" xmlns="http://www.w3.org/2000/svg" height="14.028" viewBox="0 0 14.027999 14.027999" width="14.028"><g transform="matrix(.031865 0 0 .031865 0 .013768)"><path d="m434.82 207.28-202.71-202.71c-3.609-3.617-6.655-4.856-9.133-3.713-2.475 1.143-3.712 4.189-3.712 9.137v202.71c-0.949-2.091-2.187-3.901-3.711-5.424l-202.7-202.71c-3.621-3.616-6.664-4.855-9.139-3.712-2.474 1.143-3.711 4.189-3.711 9.137v420.26c0 4.948 1.237 7.994 3.711 9.138 2.474 1.14 5.518-0.1 9.135-3.721l202.7-202.71c1.521-1.711 2.762-3.524 3.711-5.428v202.71c0 4.948 1.237 7.991 3.712 9.131 2.478 1.143 5.523-0.093 9.133-3.714l202.72-202.7c3.61-3.617 5.428-7.901 5.428-12.847-0.002-4.941-1.817-9.223-5.427-12.84z"/></g></svg>' +
            '<svg class="off" xmlns="http://www.w3.org/2000/svg" height="16.303" viewBox="0 0 16.302999 16.302999" width="16.303"><g transform="matrix(.031865 0 0 .031865 .051742 -.0054948)"><path d="m506.2 41.968c-3.617-3.617-7.902-5.426-12.851-5.426h-36.542c-4.948 0-9.232 1.809-12.847 5.426-3.62 3.619-5.427 7.902-5.427 12.851v193.57c-0.955-2.091-2.19-3.899-3.717-5.424l-202.71-202.71c-3.616-3.615-6.658-4.853-9.136-3.709-2.474 1.141-3.711 4.187-3.711 9.135v202.71c-0.95-2.091-2.187-3.899-3.709-5.424l-202.7-202.72c-3.62-3.618-6.664-4.856-9.138-3.712-2.475 1.141-3.712 4.187-3.712 9.135v420.26c0 4.948 1.241 7.998 3.715 9.141 2.474 1.14 5.518-0.099 9.135-3.72l202.71-202.7c1.52-1.708 2.76-3.519 3.709-5.421v202.71c0 4.948 1.237 7.994 3.711 9.134s5.52-0.1 9.136-3.717l202.7-202.72c1.523-1.711 2.762-3.524 3.714-5.428v193.57c0 4.948 1.81 9.229 5.427 12.847 3.614 3.617 7.898 5.425 12.847 5.425h36.546c4.944 0 9.232-1.808 12.85-5.425 3.614-3.617 5.425-7.898 5.425-12.847v-401.98c-0.005-4.956-1.811-9.235-5.428-12.851z"/></g></svg>';
    };
    
    /**
     * @method flush
     */
    this.flush = function() {
    
        var elementParent = mp.documentPlayer.querySelector('.media-control-left-panel');
        
        var element = elementParent.querySelector('.media-control-button.media-control-icon[data-autoplay]');
        
        if (element) element.parentNode.removeChild(element);
        
        this.el = document.createElement('button');
        this.el.setAttribute('data-autoplay', '');
        this.el.innerHTML = this._getButtonHTML();
        this.el.className = 'media-control-button media-control-icon' + (this.keepEnabled ? ' autoplay' : '' );
        
        if (mp.data.isSerial()) {
            elementParent.appendChild(this.el);
            
            this.el.addEventListener('click', function() {
                self._triggerButton();
                mp.player.showMessage( self.keepEnabled ? 'АВТОПЛЕЙ СЕРИЙ' : 'ОДИНОЧНЫЙ РЕЖИМ' );
            });
            this.el.addEventListener('mouseenter', function() {
                mp.player.showMessage( self.keepEnabled ? 'АВТОПЛЕЙ СЕРИЙ' : 'ОДИНОЧНЫЙ РЕЖИМ' );
            });
            this.el.addEventListener('mouseleave', mp.player.hideMessage);
        }

    };
    
    /**
     * @method next
     */
    this.next = function() {
        if (!self.keepEnabled) return false;
        
        var names = mp.playlist.getNextNames();
        
        if (names.season === null) return false;
        
        var link = mp.playlist.getUrlByNames(names.season, names.episode);
        
        mp.load(link, true);
    };
    
}