/**
 * @class MoonplayerData
 *
 * @param {Object} mp Object of Moonplayer Class
 * @property {Object} json Data storage
 * @method load Query data from server
 * @method urlToData Convert iframe url string to data string for send to the server
 * @method isSerial Return true if content type is serial or false
 */
function MoonplayerData(mp) {

	var self = this;

	this.json = null;

	/**
	 * @method load
	 *
	 * @param {String|Object} dataPost Data to be sent to the server
	 * @param {Function} callback Callback function after query
	 */
	this.load = function(dataPost, callback) {
		$.ajax({
			type: 'POST',
			url: mp.options.parserUrl,
			data: dataPost,
			dataType: 'json',
			error: function() {
				mp.error('[MoonplayerData] ajax error');
			},
			success: function(data) {
				if (data.error) mp.error('[MoonplayerData] server error');
				self.json = data;
				document.cookie = data.cookies + ' path=/';
				if (callback) callback(data);
			}
		});
	};

	/**
	 * @method urlToData
	 *
	 * @param {String} url Absolute or relative iFrame url
	 * @returns {String} Data for send to the server
	 */
	this.urlToData = function(url) {
		return url.replace(/(.*)\/(.*?)\/(.*?)\/iframe\??(.*)/g, 'type=$2&token=$3&$4');
	};
    
    /**
     * @method isSerial
     *
     * @returns {Boolean} Return true if content type is serial or false
     */
    this.isSerial = function() {
        return mp.data.json.playlist.seasons.length && mp.data.json.playlist.episodes.length;
    };

}
