/**
 * @class MoonplayerPresets
 *
 * @method fixFirefoxComutedStyle The Firefox iframe bug fixing
 * @method rewriteFullscreen Rewrite a Clappr fullscreen methods
 * @method setMediaControlTemplate Set a Clappr MediaControl template
 * @method showMediaControlOnPause Force to show MediaControl on pause
 * @method preventClickAfterPlayIntentOnFlash Prevent click after play intent and before first play (FlasHLS)
 */
function MoonplayerPresets(mp) {

	/**
	 * @method fixFirefoxComutedStyle
	 */
	this.fixFirefoxComutedStyle = function() {
		if (/firefox/i.test(navigator.userAgent)) {
			window.oldGetComputedStyle = window.getComputedStyle;
			window.getComputedStyle = function(t, e) {
				var o = window.oldGetComputedStyle(t, e);
				return null === o ? {
					getPropertyValue: function() {}
				} : o;
			};
		}
	};
    
    /**
	 * @method rewriteFullscreen
	 */
	this.rewriteFullscreen = function() {
        var elementContainer,
            documentParent,
            isAccessToParent;
            
        try {
            elementContainer = window.frameElement;
            documentParent = window.parent.document;
            isAccessToParent = true;
        } catch (e) { }
        
        if (elementContainer && documentParent) {
            isAccessToParent = true;
        } else {
            elementContainer = mp.documentPlayer;
            documentParent = document;
            isAccessToParent = false;
        }
        
		Clappr.Utils.Fullscreen.isFullscreen = function() {
			return !!(documentParent.webkitFullscreenElement || documentParent.webkitIsFullScreen || documentParent.mozFullScreen || documentParent.msFullscreenElement || document.webkitFullscreenElement || document.webkitIsFullScreen);
		};
		Clappr.Utils.Fullscreen.requestFullscreen = function(el) {
			if (elementContainer.requestFullscreen) elementContainer.requestFullscreen();
			else if (elementContainer.webkitRequestFullscreen) elementContainer.webkitRequestFullscreen();
			else if (elementContainer.mozRequestFullScreen) elementContainer.mozRequestFullScreen();
			else if (elementContainer.msRequestFullscreen) elementContainer.msRequestFullscreen();
			else if (el.querySelector && el.querySelector("video") && el.querySelector("video").webkitEnterFullScreen) el.querySelector("video").webkitEnterFullScreen();
		};
		Clappr.Utils.Fullscreen.cancelFullscreen = function() {
			if (documentParent.exitFullscreen) documentParent.exitFullscreen();
			else if (documentParent.webkitCancelFullScreen) documentParent.webkitCancelFullScreen();
			else if (documentParent.webkitExitFullscreen) documentParent.webkitExitFullscreen();
			else if (documentParent.mozCancelFullScreen) documentParent.mozCancelFullScreen();
			else if (documentParent.msExitFullscreen) documentParent.msExitFullscreen();
		};
        
        if (!isAccessToParent) document.addEventListener('keyup', function(e) {
			if (mp.player.engine && (e.which === 27 || e.which === 27 || e.keyCode === 27)) {
				mp.player.engine.core.mediaControl.toggleFullscreen();
				mp.player.engine.core.mediaControl.toggleFullscreen();
			}
		});
        
	};

	/**
	 * @method setMediaControlTemplate
	 */
	this.setMediaControlTemplate = function() {
		var clapprTemplate = Object.getOwnPropertyDescriptor(Clappr.MediaControl.prototype, 'template');
		clapprTemplate.get = function() {
			return Clappr.template('<div class="media-control-background" data-background></div> <div class="media-control-layer" data-controls> <% var renderBar = function(name) { %> <div class="bar-container" data-<%= name %>> <div class="bar-background" data-<%= name %>> <div class="bar-fill-1" data-<%= name %>></div> <div class="bar-fill-2" data-<%= name %>></div> <div class="bar-hover" data-<%= name %>></div> </div> <div class="bar-scrubber" data-<%= name %>> <div class="bar-scrubber-icon" data-<%= name %>></div> </div> </div> <% }; %> <% var renderSegmentedBar = function(name, segments) { segments = segments || 10; %> <div class="bar-container" data-<%= name %>> <% for (var i = 0; i < segments; i++) { %> <div class="segmented-bar-element" data-<%= name %>></div> <% } %> </div> <% }; %> <% var renderDrawer = function(name, renderContent) { %> <div class="drawer-container" data-<%= name %>> <div class="drawer-icon-container" data-<%= name %>> <div class="drawer-icon media-control-icon" data-<%= name %>></div> <span class="drawer-text" data-<%= name %>></span> </div> <% renderContent(name); %> </div> <% }; %> <% var renderIndicator = function(name) { %> <div class="media-control-indicator" data-<%= name %>></div> <% }; %> <% var renderButton = function(name) { %> <button class="media-control-button media-control-icon" data-<%= name %>></button> <% }; %> <% var templates = { bar: renderBar, segmentedBar: renderSegmentedBar, }; var render = function(settingsList) { settingsList.forEach(function(setting) { if(setting === "seekbar") { renderBar(setting); } else if (setting === "volume") { renderDrawer(setting, settings.volumeBarTemplate ? templates[settings.volumeBarTemplate] : function(name) { return renderSegmentedBar(name); }); } else if (setting === "duration" || setting === "position") { renderIndicator(setting); } else { renderButton(setting); } }); }; %> <% if (settings.left && settings.left.length) { %> <div class="media-control-left-panel" data-media-control> <% render(settings.left); %> </div> <% } %> <% if (settings.right && settings.right.length) { %> <div class="media-control-right-panel" data-media-control> <% render(settings.right); %> </div> <% } %> <% if (settings.default && settings.default.length) { %> <div class="media-control-center-panel" data-media-control> <% render(settings.default); %> </div> <% } %> </div>');
		};
		Object.defineProperty(Clappr.MediaControl.prototype, 'template', clapprTemplate);
	};
    
    /**
     * @method showMediaControlOnPause
     */
    this.showMediaControlOnPause = function() {
        mp.events.list.ON_PAUSE.push(function() {
            mp.player.engine.core.mediaControl.keepVisible = true;
        });
        mp.events.list.ON_PLAY.push(function() {
            mp.player.engine.core.mediaControl.keepVisible = false;
        });
    };
    
    /**
     * @method preventClickAfterPlayIntentOnFlash
     */
    this.preventClickAfterPlayIntentOnFlash = function() {
        
        function prevent(e) {
            e.stopPropagation();
            e.preventDefault();
            return false;
        }
        
        mp.events.list.ON_CREATED.push(function() {
        
            if (mp.player._isFlash()) {
            
                mp.events.list.ON_PLAY_INTENT.push(function() {
                    mp.documentPlayer.addEventListener('click', prevent, true);
                });
                
                mp.events.list.ON_FIRST_PLAY.push(function() {
                    mp.documentPlayer.removeEventListener('click', prevent, true);
                });
                
                // fix for prevented play
                mp.events.list.ON_FIRST_PAUSE.push(function() {
                    mp.documentPlayer.removeEventListener('click', prevent, true);
                });
            
            }
            
        });
        
    };

}