<?php

namespace Moonlight\Service\Authorization;

use Glue\Component\HttpFoundation\Request;
use Moonlight\Service\Condition\ConditionManager;
use Webmozart\Assert\Assert;

class Authorization
{
    protected $request;
    protected $condition;

    public function __construct(
        Request $request,
        ConditionManager $condition
    ) {
        $this->request = $request;
        $this->condition = $condition;
    }

    protected function encrypt($value)
    {
        Assert::string(
            $value,
            'Encryption value of authorization must be non-empty string, %s given.'
        );

        return hash_hmac('sha256', $value, 'asders1480481256');
    }

    public function isLogged()
    {
        $session = $this->request->getSession();

        $login    = $session->get('authorization.login');
        $password = $session->get('authorization.password');

        return $this->checkRaw($login, $password);
    }

    public function isRegistered()
    {
        $login    = $this->condition->get('authorization.login');
        $password = $this->condition->get('authorization.password');

        return $login !== null && $password !== null;
    }

    public function login($login, $password)
    {
        Assert::nullOrString(
            $login,
            'Authorization login must be a string or null, %s given.'
        );

        Assert::nullOrString(
            $password,
            'Authorization password must be a string or null, %s given.'
        );

        if ($login === null || $password === null)
            return false;

        $login    = $this->encrypt($login);
        $password = $this->encrypt($password);

        $isValid = $this->checkRaw($login, $password);

        if (!$isValid) return false;

        $session = $this->request->getSession();

        $session->set('authorization.login',    $login);
        $session->set('authorization.password', $password);

        return true;
    }

    public function logout()
    {
        $session = $this->request->getSession();

        $session->remove('authorization.login');
        $session->remove('authorization.password');
    }

    public function register($login, $password)
    {
        Assert::nullOrStringNotEmpty(
            $login,
            'Authorization login must be non-empty string or null, %s given.'
        );

        Assert::nullOrStringNotEmpty(
            $password,
            'Authorization password must be non-empty string or null, %s given.'
        );

        if ($login === null || $password === null)
            return false;

        if (!isset($login[5]) || !isset($password[7]))
            return false;

        $login    = $this->encrypt($login);
        $password = $this->encrypt($password);

        $this->condition->set('authorization.login',    $login);
        $this->condition->set('authorization.password', $password);

        return true;
    }

    protected function checkRaw($login, $password)
    {
        Assert::nullOrString(
            $login,
            'Authorization login must be a string or null, %s given.'
        );

        Assert::nullOrString(
            $password,
            'Authorization password must be a string or null, %s given.'
        );

        if ($login === null || $password === null)
            return false;

        $realLogin    = $this->condition->get('authorization.login');
        $realPassword = $this->condition->get('authorization.password');

        return $login === $realLogin && $password === $realPassword;
    }

    public function check($login, $password)
    {
        Assert::nullOrString(
            $login,
            'Authorization login must be a string or null, %s given.'
        );

        Assert::nullOrString(
            $password,
            'Authorization password must be a string or null, %s given.'
        );

        if ($login === null || $password === null)
            return false;

        $login    = $this->encrypt($login);
        $password = $this->encrypt($password);

        return $this->checkRaw($login, $password);
    }
}