<?php

namespace Moonlight\Service\Condition;

use Webmozart\Assert\Assert;

class ConditionManager implements ConditionInterface
{
    protected $file;
    protected $condition;

    public function __construct($file)
    {
        Assert::stringNotEmpty(
            $file,
            'Path to the condition file must be not empty string, %s given.'
        );

        if (!file_exists($file)) {

            Assert::true(
                @touch($file),
                "No access to write the condition file \"$file\"."
            );
        }

        $path = realpath($file);

        Assert::false(
            is_dir($path),
            'The condition file is invalid, directory given.'
        );

        Assert::true(
            is_readable($path),
            "The condition file \"$path\" is not readable."
        );

        $contents = file_get_contents($path);

        $condition = json_decode($contents, true);

        $this->file = $path;
        $this->condition = $condition ?: [];
    }

    public function get($name)
    {
        return isset($this->condition[$name])
            ? $this->condition[$name]
            : null;
    }

    public function set($name, $value)
    {
        Assert::stringNotEmpty(
            $name,
            'Condition name must be not empty string, %s given.'
        );

        if (
            $value === null
            && isset($this->condition[$name])
        ) {

            unset($this->condition[$name]);

        } else {

            $this->condition[$name] = $value;

        }

        return (boolean) $this->commit();
    }

    protected function commit()
    {
        Assert::stringNotEmpty(
            $this->file,
            'To commit condition the value of "file" field must be not empty string, %s given.'
        );

        Assert::file(
            $this->file,
            'Path to the condition file %s is not a file.'
        );

        Assert::writable(
            $this->file,
            'Path to the condition file %s is not writable.'
        );

        $contents = json_encode($this->condition);

        return file_put_contents(
            $this->file,
            $contents
        );
    }
}