<?php

namespace Moonlight\Utils;

use Webmozart\Assert\Assert;

class ParserTools
{
    public static function getRandUserAgent()
    {
        $list = [
            'Mozilla/5.0 (Linux; Android 5.1.1; SM-G928X Build/LMY47X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/47.0.2526.83 Mobile Safari/537.36',
            'Mozilla/5.0 (Windows Phone 10.0; Android 4.2.1; Microsoft; Lumia 950) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/46.0.2486.0 Mobile Safari/537.36 Edge/13.10586',
            'Mozilla/5.0 (Linux; Android 6.0.1; Nexus 6P Build/MMB29P) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/47.0.2526.83 Mobile Safari/537.36',
            'Mozilla/5.0 (Linux; Android 5.0.2; SAMSUNG SM-T550 Build/LRX22G) AppleWebKit/537.36 (KHTML, like Gecko) SamsungBrowser/3.3 Chrome/38.0.2125.102 Safari/537.36',
            'Mozilla/5.0 (Linux; Android 4.4.3; KFTHWI Build/KTU84M) AppleWebKit/537.36 (KHTML, like Gecko) Silk/47.1.79 like Chrome/47.0.2526.80 Safari/537.36',
            'Mozilla/5.0 (Linux; Android 5.0.2; LG-V410/V41020c Build/LRX22G) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/34.0.1847.118 Safari/537.36'
        ];

        return $list[rand(0, count($list) -1)];
    }

    public static function genPlayerUrl(
        $protocol,
        $host,
        $type,
        $token,
        array $query
    ) {
        Assert::stringNotEmpty(
            $protocol,
            'Protocol of the player url must be not empty string, %s given.'
        );

        Assert::stringNotEmpty(
            $host,
            'Host name of the player url must be not empty string, %s given.'
        );

        Assert::stringNotEmpty(
            $type,
            'Type parameter of the player url must be not empty string, %s given.'
        );

        Assert::stringNotEmpty(
            $token,
            'Token parameter of the player url must be not empty string, %s given.'
        );

        $queryString = self::genPlayerQueryString($query);

        $url = $protocol .'://'. $host .'/'. $type .'/'. $token .'/iframe'
            . ($queryString ? '?'. $queryString : '');

        return $url;
    }

    public static function genPlayerQueryString(array $query)
    {
        $array = [];

        if (isset($query['retrans']))
            $array['retrans'] = $query['retrans'];

        if (isset($query['nocontrols']))
            $array['nocontrols'] = $query['nocontrols'];

        if (isset($query['nocontrols_seasons']))
            $array['nocontrols_seasons'] = $query['nocontrols_seasons'];

        if (isset($query['nocontrols_translations']))
            $array['nocontrols_translations'] = $query['nocontrols_translations'];

        if (isset($query['season']))
            $array['season'] = $query['season'];

        if (isset($query['episode']))
            $array['episode'] = $query['episode'];

        return http_build_query($array);
    }

    public static function refererAllowed(
        $referer,
        array $list
    ) {
        Assert::nullOrString(
            $referer,
            'Unable to match referer in list, value of referer must be a string or null, %s given.'
        );

        if (!$referer) return true;

        $list[] = $_SERVER['HTTP_HOST'];

        $host = parse_url($referer, PHP_URL_HOST);

        if (!$host) return false;

        return array_search($host, $list) !== false
            ? true
            : false;
    }
}