<?php

namespace Glue\Component\Controller;

use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Controller\ControllerResolver as BaseControllerResolver;
use Webmozart\Assert\Assert;

class ControllerResolver extends BaseControllerResolver
{
    protected $container;

    /**
     * Get the controller and action name
     * from string of controller definition.
     *
     * @param string $controller
     * @return array
     */
    static public function getNames($controller)
    {
        Assert::stringNotEmpty(
            $controller,
            'Invalid type for controller given, expected a non-empty string, got %s.'
        );

        preg_match('/\W(\w+?)(?:Controller)?::?(\w+?)(?:Action)?$/', $controller, $matches);

        Assert::count(
            $matches, 3,
            sprintf(
                'Unsupported syntax of controller string, "%s" given.',
                $controller
            )
        );

        return [
            'controller' => $matches[1],
            'action'     => $matches[2]
        ];
    }

    public function __construct(ContainerInterface $container, LoggerInterface $logger = null)
    {
        $this->container = $container;

        parent::__construct($logger);
    }

    /**
     * {@inheritdoc}
     */
    protected function instantiateController($class)
    {
        if ($this->container->has($class)) {
            return $this->container->get($class);
        }
        $controller = parent::instantiateController($class);
        if ($controller instanceof ContainerAwareInterface) {
            $controller->setContainer($this->container);
        }
        return $controller;
    }
}