<?php

namespace Glue\Component\HttpFoundation;

use Symfony\Component\HttpFoundation\Request as BaseRequest;
use Webmozart\Assert\Assert;

class Request extends BaseRequest
{
    public function getQuery($name)
    {
        Assert::stringNotEmpty(
            $name,
            'Query parameter must be non-empty string, %s given.'
        );

        Assert::true(
            $this->query->has($name),
            "You have requested a non-existent GET parameter \"$name\" from request."
        );

        return $this->query->get($name);
    }

    public function getRequest($name)
    {
        Assert::stringNotEmpty(
            $name,
            'Request parameter must be non-empty string, %s given.'
        );

        Assert::true(
            $this->request->has($name),
            "You have requested a non-existent POST parameter \"$name\" from request."
        );

        return $this->request->get($name);
    }

    public function getAttribute($name)
    {
        Assert::stringNotEmpty(
            $name,
            'Attribute parameter must be non-empty string, %s given.'
        );

        Assert::true(
            $this->attributes->has($name),
            "You have requested a non-existent attribute \"$name\" from request."
        );

        return $this->attributes->get($name);
    }

    public function getCookie($name)
    {
        Assert::stringNotEmpty(
            $name,
            'Cookie name must be non-empty string, %s given.'
        );

        Assert::true(
            $this->cookies->has($name),
            "You have requested a non-existent cookie \"$name\" from request."
        );

        return $this->cookies->get($name);
    }

    public function getServer($name)
    {
        Assert::stringNotEmpty(
            $name,
            'Server parameter must be non-empty string, %s given.'
        );

        Assert::true(
            $this->server->has($name),
            "You have requested a non-existent server parameter \"$name\" from request."
        );

        return $this->server->get($name);
    }
}