<?php

namespace Glue\Component\HttpFoundation;

use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerAwareTrait;
use Symfony\Component\HttpFoundation\Response as BaseResponse;

class Response extends BaseResponse implements
    LoggerAwareInterface
{
    use LoggerAwareTrait;

    /**
     * Set content, status and headers array
     *
     * @param  string $content
     * @param  int    $status
     * @param  array  $headers
     * @return $this
     */
    public function set($content = null, $status = null, array $headers = null)
    {
        if ($content !== null) $this->setContent($content);
        if ($status  !== null) $this->setStatusCode($status);
        if ($headers !== null) $this->headers->add($headers);

        return $this;
    }

    /**
     * Send response to output
     *
     * @return BaseResponse
     */
    public function send()
    {
        if ($this->logger)
            $this->logger->debug(sprintf(
                'Response sent with status code %d and body size of %d bytes.',
                $this->getStatusCode(),
                strlen($this->getContent())
            ));

        return parent::send();
    }
}